#!/bin/sh
export PATH='/usr/obj/hs-MonadCatchIO-mtl-0.3.1.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: MonadCatchIO-mtl
version: 0.3.1.0
id: MonadCatchIO-mtl-0.3.1.0-302ee90ea16ac5204cc7483e0197ef9d

license: BSD3
copyright:
maintainer: jcpetruzza@gmail.com
stability:
homepage: http://darcsden.com/jcpetruzza/MonadCatchIO-mtl
package-url:
synopsis: Monad-transformer version of the Control.Exception module
description: Provides a monad-transformer version of the @Control.Exception.catch@
             function. For this, it defines the @MonadCatchIO@ class, a subset of
             @MonadIO@. It defines proper instances for most monad transformers in
             the '\''mtl'\'' library.
category: Control
author:
pkgpath: devel/hs-MonadCatchIO-mtl
exposed: True
exposed-modules: Control.Monad.CatchIO
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.1.0
library-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.1.0
hs-libraries: HSMonadCatchIO-mtl-0.3.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: MonadCatchIO-transformers-0.3.1.2-62247321324d3e4a539fd9759ef95eea
         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         extensible-exceptions-0.1.1.4-ff00541964e8b4f6fe7adae94cd5f3b4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.1.0/html/MonadCatchIO-mtl.haddock
haddock-html: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.1.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
